@@ -1,17 +1,15 @@
 package org.softwareheritage.graph.benchmark;
 
+import com.martiansoftware.jsap.JSAPException;
+import org.softwareheritage.graph.Graph;
+import org.softwareheritage.graph.server.Endpoint;
+
 import java.io.IOException;
 
-import com.martiansoftware.jsap.JSAPException;
-
-import org.softwareheritage.graph.Endpoint;
-import org.softwareheritage.graph.Graph;
-import org.softwareheritage.graph.benchmark.Benchmark;
-
 /**
- * Benchmark Software Heritage <a
- * href="https://docs.softwareheritage.org/devel/swh-graph/use-cases.html#vault">vault
- * use-case scenario</a>.
+ * Benchmark Software Heritage
+ * <a href="https://docs.softwareheritage.org/devel/swh-graph/use-cases.html#vault">vault use-case
+ * scenario</a>.
  *
  * @author The Software Heritage developers
  */
