@@ -12,7 +12,16 @@ class GraphAPIError(Exception):
     """Graph API Error"""
 
     def __str__(self):
-        return "An unexpected error occurred in the Graph backend: {}".format(self.args)
+        return """An unexpected error occurred
+               in the Graph backend: {}""".format(
+            self.args
+        )
+
+
+class GraphArgumentException(Exception):
+    def __init__(self, *args, response=None):
+        super().__init__(*args)
+        self.response = response
 
 
 class RemoteGraphClient(RPCClient):
@@ -30,27 +39,55 @@ class RemoteGraphClient(RPCClient):
     def get_lines(self, endpoint, **kwargs):
         yield from self.raw_verb_lines("get", endpoint, **kwargs)
 
+    def raise_for_status(self, response) -> None:
+        if response.status_code // 100 == 4:
+            raise GraphArgumentException(
+                response.content.decode("ascii"), response=response
+            )
+        super().raise_for_status(response)
+
     # Web API endpoints
 
     def stats(self):
         return self.get("stats")
 
-    def leaves(self, src, edges="*", direction="forward", max_edges=0):
+    def leaves(
+        self, src, edges="*", direction="forward", max_edges=0, return_types="*"
+    ):
         return self.get_lines(
             "leaves/{}".format(src),
-            params={"edges": edges, "direction": direction, "max_edges": max_edges},
+            params={
+                "edges": edges,
+                "direction": direction,
+                "max_edges": max_edges,
+                "return_types": return_types,
+            },
         )
 
-    def neighbors(self, src, edges="*", direction="forward", max_edges=0):
+    def neighbors(
+        self, src, edges="*", direction="forward", max_edges=0, return_types="*"
+    ):
         return self.get_lines(
             "neighbors/{}".format(src),
-            params={"edges": edges, "direction": direction, "max_edges": max_edges},
+            params={
+                "edges": edges,
+                "direction": direction,
+                "max_edges": max_edges,
+                "return_types": return_types,
+            },
         )
 
-    def visit_nodes(self, src, edges="*", direction="forward", max_edges=0):
+    def visit_nodes(
+        self, src, edges="*", direction="forward", max_edges=0, return_types="*"
+    ):
         return self.get_lines(
             "visit/nodes/{}".format(src),
-            params={"edges": edges, "direction": direction, "max_edges": max_edges},
+            params={
+                "edges": edges,
+                "direction": direction,
+                "max_edges": max_edges,
+                "return_types": return_types,
+            },
         )
 
     def visit_edges(self, src, edges="*", direction="forward", max_edges=0):
@@ -86,11 +123,18 @@ class RemoteGraphClient(RPCClient):
             },
         )
 
-    def random_walk(self, src, dst, edges="*", direction="forward", limit=None):
+    def random_walk(
+        self, src, dst, edges="*", direction="forward", limit=None, return_types="*"
+    ):
         endpoint = "randomwalk/{}/{}"
         return self.get_lines(
             endpoint.format(src, dst),
-            params={"edges": edges, "direction": direction, "limit": limit},
+            params={
+                "edges": edges,
+                "direction": direction,
+                "limit": limit,
+                "return_types": return_types,
+            },
         )
 
     def count_leaves(self, src, edges="*", direction="forward"):
